<?php

namespace Bixo\Tables\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Tables\Models\BixoCrmLead;

class BixoCrmLeadPolicy
{

    /**
     * Determine if the given user can view the bixo_crm_lead.
     *
     * @param UserPolicy $user
     * @param BixoCrmLead $bixo_crm_lead
     *
     * @return bool
     */
    public function view(UserPolicy $user, BixoCrmLead $bixo_crm_lead)
    {
        if ($user->canDo('tables.bixo_crm_lead.view') && $user->isAdmin()) {
            return true;
        }

        return $bixo_crm_lead->user_id == user_id() && $bixo_crm_lead->user_type == user_type();
    }

    /**
     * Determine if the given user can create a bixo_crm_lead.
     *
     * @param UserPolicy $user
     * @param BixoCrmLead $bixo_crm_lead
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('tables.bixo_crm_lead.create');
    }

    /**
     * Determine if the given user can update the given bixo_crm_lead.
     *
     * @param UserPolicy $user
     * @param BixoCrmLead $bixo_crm_lead
     *
     * @return bool
     */
    public function update(UserPolicy $user, BixoCrmLead $bixo_crm_lead)
    {
        if ($user->canDo('tables.bixo_crm_lead.edit') && $user->isAdmin()) {
            return true;
        }

        return $bixo_crm_lead->user_id == user_id() && $bixo_crm_lead->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given bixo_crm_lead.
     *
     * @param UserPolicy $user
     * @param BixoCrmLead $bixo_crm_lead
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BixoCrmLead $bixo_crm_lead)
    {
        return $bixo_crm_lead->user_id == user_id() && $bixo_crm_lead->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given bixo_crm_lead.
     *
     * @param UserPolicy $user
     * @param BixoCrmLead $bixo_crm_lead
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BixoCrmLead $bixo_crm_lead)
    {
        if ($user->canDo('tables.bixo_crm_lead.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given bixo_crm_lead.
     *
     * @param UserPolicy $user
     * @param BixoCrmLead $bixo_crm_lead
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BixoCrmLead $bixo_crm_lead)
    {
        if ($user->canDo('tables.bixo_crm_lead.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
